==> kmediaplayer-5.11.0.tar.xz: kmediaplayer-5.11.0/autotests/testplayer.h <==
/*
 * Copyright 2013  Alex Merry <alex.merry@kdemail.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of the X Consortium shall not be
 * used in advertising or otherwise to promote the sale, use or other dealings
 * in this Software without prior written authorization from the X Consortium.
 */

#ifndef TESTPLAYER_H
#define TESTPLAYER_H

#include <kmediaplayer/player.h>

class TestPlayer : public KMediaPlayer::Player
{
    Q_OBJECT

public:
    TestPlayer(QObject *parent) : Player(parent) {}

    KMediaPlayer::View *view()
    {
        return 0;
    }
    void pause() {}
    void play() {}
    void stop() {}
    void seek(qlonglong) {}
    bool isSeekable() const
    {
        return false;
    }
    qlonglong position() const
    {
        return 0L;
    }
    bool hasLength() const
    {
        return false;
    }
    qlonglong length() const
    {
        return 0L;
    }

    void setStateWrapper(State state)
    {
        // this is protected
        setState(state);
    }
};

#endif // TESTPLAYER_H

==> kmediaplayer-5.26.0.tar.xz: kmediaplayer-5.26.0/autotests/testplayer.h <==
/*
 * Copyright 2013  Alex Merry <alex.merry@kdemail.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of the X Consortium shall not be
 * used in advertising or otherwise to promote the sale, use or other dealings
 * in this Software without prior written authorization from the X Consortium.
 */

#ifndef TESTPLAYER_H
#define TESTPLAYER_H

#include <kmediaplayer/player.h>

class TestPlayer : public KMediaPlayer::Player
{
    Q_OBJECT

public:
    TestPlayer(QObject *parent) : Player(parent) {}

    KMediaPlayer::View *view() Q_DECL_OVERRIDE
    {
        return 0;
    }
    void pause() Q_DECL_OVERRIDE
    {
    }
    void play() Q_DECL_OVERRIDE
    {
    }
    void stop() Q_DECL_OVERRIDE
    {
    }
    void seek(qlonglong) Q_DECL_OVERRIDE
    {
    }
    bool isSeekable() const Q_DECL_OVERRIDE
    {
        return false;
    }
    qlonglong position() const Q_DECL_OVERRIDE
    {
        return 0L;
    }
    bool hasLength() const Q_DECL_OVERRIDE
    {
        return false;
    }
    qlonglong length() const Q_DECL_OVERRIDE
    {
        return 0L;
    }

    void setStateWrapper(State state)
    {
        // this is protected
        setState(state);
    }
};

#endif // TESTPLAYER_H
